<?php

namespace app\admin\service\order;

use app\model\Appointment;
use app\model\Goods;
use app\model\MemberBenefit;
use app\model\SysSerial;
use support\Db;
use support\Request;
use function _PHPStan_cc8d35ffb\RingCentral\Psr7\str;

class AppointmentService
{
    public static function select(Request $request)
    {
        $page = $request->get('page');
        $pageSize = $request->get('pageSize');
        $id = $request->get('id', '');
        $mobile = $request->get('mobile', '');
        $status = $request->get('status', '');


        $rows = Db::table('appointment')
            ->leftJoin('member', 'member.member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('member_cert', 'member_cert.join_cert_member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('member_info', 'member_info.join_info_member_id', '=', 'appointment.join_appointment_member_id')
            ->leftJoin('goods', 'goods.goods_id', '=', 'appointment.join_appointment_goods_id')
            ->leftJoin('order', 'order.order_id', '=', 'appointment.join_appointment_order_id')
            ->leftJoin('member_benefit', 'member_benefit.member_benefit_id', '=', 'appointment.join_appointment_member_benefit_id')
            ->leftJoin('goods_sku', 'goods_sku.goods_sku_id', '=', 'appointment.join_appointment_goods_sku_id')
            ->when($id != '', function ($query) use ($id) {
                $query->where('appointment.appointment_id', 'like', '%' . $id . '%');
            })->when($mobile != '', function ($query) use ($mobile) {
                $query->where('member.member_mobile', 'like', '%' . $mobile . '%');
            })->when($status != '', function ($query) use ($status) {
                $query->where('appointment.appointment_status', $status);
            });

        $total = $rows->count('member.member_id');
        $rows = $rows->select('appointment.*',
            'member.member_mobile',
            'member_cert.member_cert_name',
            'member_info.member_info_nickname',
            'goods.goods_name', 'goods.goods_cover', 'goods.goods_sales_price',
            'order.order_name', 'goods_sku.goods_sku_specs_json', 'order.order_amount_total', 'order.order_amount_pay',
            'order.order_category', 'order.order_status_system', 'order.order_status_payment', 'order.order_status_storage',
            'order.order_addtimes',
            'member_benefit.member_benefit_name'
        )
            ->orderBy('appointment.appointment_addtimes', 'desc')
            ->forPage($page, $pageSize)
            ->get();

        foreach ($rows as &$row) {
            $row->goods_cover = getenv('STORAGE_DOMAIN') . $row->goods_cover;
            $row->goods_sku_specs_json = !empty($row->goods_sku_specs_json) ? json_decode($row->goods_sku_specs_json, true) : [];
            $row->order_addtimes = date('Y-m-d H:i:s', $row->order_addtimes);
            $row->appointment_addtimes = date('Y-m-d H:i:s', $row->appointment_addtimes);
            if ($row->appointment_category == 'NOFEE') {
                $row->member_benefit_name = "后付费预约";
            }
        }

        return json_success('', compact('rows', 'page', 'pageSize', 'total'));
    }

    public static function confirm($id)
    {
        $appointment = Appointment::where('appointment_id', $id)->where('appointment_status', 'WAITING')->first();
        if (!$appointment) {
            return json_fail('数据异常');
        }

        try {
            $appointment->appointment_status = 'PENDING';
            $appointment->save();

            return json_success('操作成功');
        } catch (\Exception $e) {
            dump($e->getMessage());
            return json_fail("操作失败");
        }
    }

    public static function add(Request $request)
    {
        $params = $request->post();
        Db::beginTransaction();
        try {
            $data = [
                'appointment_id' => "AP" . str_pad(SysSerial::getSerial(), 16, '0') . random_string(6, 'up'),
                'join_appointment_member_id' => $params['join_appointment_member_id'] ?? '',
                'join_appointment_goods_id' => $params['join_appointment_goods_id'] ?? '',
                'appointment_status' => $params['appointment_status'] ?? '',
                'appointment_datetime' => isset($params['appointment_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_datetime'])) : '',
                'appointment_apply_datetime' => isset($params['appointment_apply_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_apply_datetime'])) : '',
                'appointment_doing_datetime' => isset($params['appointment_doing_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_doing_datetime'])) : '',
                'appointment_done_datetime' => isset($params['appointment_done_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_done_datetime'])) : '',
                'appointment_cancel_datetime' => isset($params['appointment_cancel_datetime']) ? date('Y-m-d H:i:s', strtotime($params['appointment_cancel_datetime'])) : '',
                'appointment_remark' => $params['appointment_remark'] ?? '',
                'appointment_category' => 'NOFEE',
                'appointment_addtimes' => time(),
            ];

            Appointment::insert($data);

            Db::commit();
            return json_success("添加预约成功");
        } catch (\Exception $e) {
            Db::rollBack();
            dump($e->getMessage());
            return json_fail("添加预约失败");
        }
    }


    public static function update(Request $request)
    {
        $appointmentId = $request->post('appointment_id');
        $appointment = Appointment::where('appointment_id', $appointmentId)->first();
        if (!$appointment) {
            return json_fail("数据不存在");
        }
        $params = $request->post();
        Db::beginTransaction();
        try {
            $data = [
                'appointment_status' => $params['appointment_status'],
                'appointment_datetime' => $params['appointment_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_datetime'])) : null,
                'appointment_apply_datetime' => $params['appointment_apply_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_apply_datetime'])) : null,
                'appointment_doing_datetime' => $params['appointment_doing_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_doing_datetime'])) : null,
                'appointment_done_datetime' => $params['appointment_done_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_done_datetime'])) : null,
                'appointment_cancel_datetime' => $params['appointment_cancel_datetime'] ? date('Y-m-d H:i:s', strtotime($params['appointment_cancel_datetime'])) : null,
                'appointment_remark' => $params['appointment_remark'] ?? '',
            ];

            Appointment::where('appointment_id', $appointmentId)->update($data);
            // 如果是完成状态
            if ($params['appointment_status'] == 'DONE' && $appointment->appointment_status != 'DONE') {
                MemberBenefit::where('member_benefit_id', $appointment->join_appointment_member_benefit_id)->increment('member_benefit_used_count');
            }

            Db::commit();
            return json_success("数据更新成功");
        } catch (\Exception $e) {
            Db::rollBack();
            dump($e->getMessage());
            return json_fail("数据更新失败");
        }
    }
}